/*
 * @author norbert
 * @date 28.08.2008
 * @version $Id: EventReceiverPortlet.java,v 1.1 2008-08-28 14:43:36 norbert Exp $
 */
package com.gentics.portalnode.sdk.events;

import java.io.IOException;
import java.io.PrintWriter;

import javax.portlet.EventRequest;
import javax.portlet.EventResponse;
import javax.portlet.GenericPortlet;
import javax.portlet.PortletException;
import javax.portlet.PortletSession;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

/**
 * Implementation of a portlet that counts, how often a specific event is received
 */
public class EventReceiverPortlet extends GenericPortlet {
    /**
     * name of the portlet session attribute for the event counter
     */
    protected final static String COUNTER_NAME = "eventCounter";

    /* (non-Javadoc)
     * @see javax.portlet.GenericPortlet#doView(javax.portlet.RenderRequest, javax.portlet.RenderResponse)
     */
    protected void doView(RenderRequest request, RenderResponse response)
            throws PortletException, IOException {
        PortletSession portletSession = request.getPortletSession();
        int eventsCount = getEventCounterFromSession(portletSession);

        PrintWriter writer = response.getWriter();
        writer.println("This is the event receiving portlet.<br/>");
        writer.println("Received " + eventsCount + " events so far.");
    }

    /* (non-Javadoc)
     * @see javax.portlet.GenericPortlet#processEvent(javax.portlet.EventRequest, javax.portlet.EventResponse)
     */
    public void processEvent(EventRequest request, EventResponse response)
            throws PortletException, IOException {
        if (EventSenderPortlet.EVENT_NAME.equals(request.getEvent().getName())) {
            // get the events counter from the session
            PortletSession portletSession = request.getPortletSession();
            int eventsCount = getEventCounterFromSession(portletSession);

            // increase the counter
            eventsCount++;

            // store the new value back
            portletSession.setAttribute(COUNTER_NAME, new Integer(eventsCount), PortletSession.PORTLET_SCOPE);
        }
    }

    /**
     * Get the events count from the session
     * @param portletSession portlet session
     * @return events count
     */
    protected int getEventCounterFromSession(PortletSession portletSession) {
        int eventsCount = 0;

        // get the event counter from the session
        Object eventCounter = portletSession.getAttribute(COUNTER_NAME,
                PortletSession.PORTLET_SCOPE);
        if (eventCounter instanceof Integer) {
            eventsCount = ((Integer) eventCounter).intValue();
        }

        return eventsCount;
    }
}
