package com.gentics.portalnode.sdk.filter;

import java.util.Iterator;
import java.util.List;

import com.gentics.api.lib.etc.ObjectTransformer;
import com.gentics.api.lib.expressionparser.EvaluationException;
import com.gentics.api.lib.expressionparser.filtergenerator.PostProcessor;
import com.gentics.api.lib.resolving.Resolvable;

/**
 * PostProcessor to filter objects that have attributes starting with a given string
 * Usage: filter([rule], 'com.gentics.portalnode.sdk.filter.StartsWith', ['firstname', 'a'])
 */
public class StartsWith implements PostProcessor {
	/* (non-Javadoc)
	 * @see com.gentics.api.lib.expressionparser.filtergenerator.PostProcessor#process(java.util.List, java.lang.Object)
	 */
	public void process(List<Resolvable> resolvables, Object data)
			throws EvaluationException {
		// read the attribute name and prefix
		String attributeName = "firstname";
		String prefix = "a";
		String[] dataArray = ObjectTransformer.getStringArray(data,
				new String[] { attributeName, prefix });
		if (dataArray.length >= 1) {
			attributeName = dataArray[0];
		}
		if (dataArray.length >= 2) {
			prefix = dataArray[1];
		}

		// filter out the objects, that do not start with the required prefix
		for (Iterator<Resolvable> i = resolvables.iterator(); i.hasNext();) {
			Resolvable res = i.next();
			if (!ObjectTransformer.getString(res.get(attributeName), "").startsWith(prefix)) {
				i.remove();
			}
		}
	}
}
